==> kdepim-3.3.2.tar.bz2: kdepim-3.3.2/kpilot/conduits/notepadconduit/notepad-conduit.h <==
#ifndef _KPILOT_NOTEPAD_CONDUIT_H
#define _KPILOT_NOTEPAD_CONDUIT_H
/* notepad-conduit.h			KPilot
**
** Copyright (C) 2004 by Adriaan de Groot, Joern Ahrens, Angus Ainslie
**
** The code for NotepadActionThread::unpackNotePad was taken from 
** Angus Ainslies read-notepad.c, which is part of pilot-link.
** NotepadActionThread::saveImage is also based on read-notepad.c.
**
** This file is part of the Notepad conduit, a conduit for KPilot that
** store the notepad drawings to files.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU Lesser General Public License as published by
** the Free Software Foundation; either version 2.1 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU Lesser General Public License for more details.
**
** You should have received a copy of the GNU Lesser General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
** MA 02111-1307, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include "plugin.h"

#include <qthread.h>
struct NotePad;
class NotepadActionThread;

class NotepadConduit : public ConduitAction
{
public:
	NotepadConduit(KPilotDeviceLink *,
		const char *name=0L,
		const QStringList &args = QStringList());
	virtual ~NotepadConduit();
	virtual bool event(QEvent *e);
	
protected:
	virtual bool exec();           // From ConduitAction
	
private:
	NotepadActionThread *thread;
};


/**
 * This class saves the notepads to disk
 */
class NotepadActionThread : public QThread
{
public:
	NotepadActionThread(QObject *parent, int pilotSocket);

	virtual void run();
	int	getFailed() { return notSaved; }
	int getSaved() { return saved; }
		
private:
	QObject *fParent;
	int fPilotSocket;
	/**
	 * counts how many notepads couldn't be saved during the sync
	 */
	int notSaved;
	/**
	 * counts how many files a saved during the sync
	 */
	int saved;
	
	int unpackNotePad(struct NotePad *a, unsigned char *buffer, int len);
	void saveImage(struct NotePad *n);
};

#endif

==> kdepim-3.5.5.tar.bz2: kdepim-3.5.5/kpilot/conduits/notepadconduit/notepad-conduit.h <==
#ifndef _KPILOT_NOTEPAD_CONDUIT_H
#define _KPILOT_NOTEPAD_CONDUIT_H
/* notepad-conduit.h			KPilot
**
** Copyright (C) 2004 by Adriaan de Groot, Joern Ahrens, Angus Ainslie
**
** The code for NotepadActionThread::unpackNotePad was taken from 
** Angus Ainslies read-notepad.c, which is part of pilot-link.
** NotepadActionThread::saveImage is also based on read-notepad.c.
**
** This file is part of the Notepad conduit, a conduit for KPilot that
** store the notepad drawings to files.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU Lesser General Public License as published by
** the Free Software Foundation; either version 2.1 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU Lesser General Public License for more details.
**
** You should have received a copy of the GNU Lesser General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
** MA 02110-1301, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include "plugin.h"

#include <qthread.h>
struct NotePad;
class NotepadActionThread;

class NotepadConduit : public ConduitAction
{
public:
	NotepadConduit(KPilotDeviceLink *,
		const char *name=0L,
		const QStringList &args = QStringList());
	virtual ~NotepadConduit();
	virtual bool event(QEvent *e);
	
protected:
	virtual bool exec();           // From ConduitAction
	
private:
	NotepadActionThread *thread;
};


/**
 * This class saves the notepads to disk
 */
class NotepadActionThread : public QThread
{
public:
	NotepadActionThread(QObject *parent, int pilotSocket);

	virtual void run();
	int	getFailed() { return notSaved; }
	int getSaved() { return saved; }
		
private:
	QObject *fParent;
	int fPilotSocket;
	/**
	 * counts how many notepads couldn't be saved during the sync
	 */
	int notSaved;
	/**
	 * counts how many files a saved during the sync
	 */
	int saved;
	
	int unpackNotePad(struct NotePad *a, unsigned char *buffer, int len);
	void saveImage(struct NotePad *n);
};

#endif
